searchData={"items":[{"type":"protocol","title":"IOData","doc":"A protocol for working with various data types such as binaries and iolists.\n\nThis protocol defines a set of functions for performing common operations on\ndata, including:\n\n- Checking if the data has at least a specified number of bytes.\n- Retrieving the size of the data in bytes.\n- Splitting the data at a specified byte offset.\n- Checking if the data starts with a given binary prefix.\n- Converting the data to iodata or binary formats.\n- Extracting portions of the data as iodata or binary.\n\nImplementations of this protocol should be efficient and avoid unnecessary\ncopying of data whenever possible.","ref":"IOData.html"},{"type":"function","title":"IOData.at_least?/2","doc":"Checks if the given data has at least the specified number of bytes.","ref":"IOData.html#at_least?/2"},{"type":"function","title":"IOData.size/1","doc":"Returns the total size, in bytes, of the given data.","ref":"IOData.html#size/1"},{"type":"function","title":"IOData.split/2","doc":"Splits data at the specified byte offset if possible, returning either {:ok, {prefix, suffix}} or an error tuple.","ref":"IOData.html#split/2"},{"type":"function","title":"IOData.starts_with?/2","doc":"Checks if the given data starts with the specified binary prefix.","ref":"IOData.html#starts_with?/2"},{"type":"type","title":"IOData.t/0","doc":"","ref":"IOData.html#t:t/0"},{"type":"function","title":"IOData.to_binary/1","doc":"Converts the entire data into a binary.","ref":"IOData.html#to_binary/1"},{"type":"function","title":"IOData.to_binary/3","doc":"Extracts a portion of the data as a binary, starting at 'start' for 'count' bytes. Returns an ok/error tuple.","ref":"IOData.html#to_binary/3"},{"type":"function","title":"IOData.to_binary!/1","doc":"Same as to_binary/0 but raises an error if the data is insufficient.","ref":"IOData.html#to_binary!/1"},{"type":"function","title":"IOData.to_binary!/3","doc":"Same as to_binary/3 but raises an error if the data is insufficient.","ref":"IOData.html#to_binary!/3"},{"type":"function","title":"IOData.to_iodata/1","doc":"Returns the data in iodata form without modifying it.","ref":"IOData.html#to_iodata/1"},{"type":"function","title":"IOData.to_iodata/3","doc":"Extracts a portion of the data as iodata, starting at 'start' for 'count' bytes. Returns an ok/error tuple.","ref":"IOData.html#to_iodata/3"},{"type":"function","title":"IOData.to_iodata!/1","doc":"Same as to_iodata/0 but raises an error if the data is insufficient.","ref":"IOData.html#to_iodata!/1"},{"type":"function","title":"IOData.to_iodata!/3","doc":"Same as to_iodata/3 but raises an error if the data is insufficient.","ref":"IOData.html#to_iodata!/3"},{"type":"module","title":"IOData.File","doc":"A structure that represents a file and can be used with IOData. A `File` can\nbe opened or wrapped around an existing file-descriptor or reference.","ref":"IOData.File.html"},{"type":"module","title":"Examples - IOData.File","doc":"iex> {:ok, slice} = IOData.File.open(\"path/to/file\")\n    iex> IOData.to_binary(slice)\n    {:ok, <<0, 1, 2, 3, 4, 5, 6, 7, 8, 9>>}\n\n    iex> {head, tail} = IOData.split!(slice, 5)\n    iex> IOData.to_binary(tail)\n    {:ok, <<5, 6, 7, 8, 9>>}","ref":"IOData.File.html#module-examples"},{"type":"function","title":"IOData.File.open/1","doc":"Opens a file and returns a slice that can be used with IOData. The slice\nrepresents the entire file.","ref":"IOData.File.html#open/1"},{"type":"function","title":"IOData.File.open!/1","doc":"Opens a file and returns a slice that can be used with IOData. The slice\nrepresents the entire file. If the file cannot be opened, an exception is\nraised.","ref":"IOData.File.html#open!/1"},{"type":"type","title":"IOData.File.t/0","doc":"","ref":"IOData.File.html#t:t/0"},{"type":"function","title":"IOData.File.wrap/3","doc":"Wraps an existing file or reference in a slice that can be used with IOData. A\nlength is required in order to provide boundary checking.","ref":"IOData.File.html#wrap/3"}],"proglang":"elixir","content_type":"text/markdown","producer":{"name":"ex_doc","version":"0.36.1"}}